@@ -5,7 +5,7 @@
 
 ;; Emacs 19 byte compiler complains about too much stuff by default.
 ;; Turn off most of the warnings here.
-(setq byte-compile-warnings nil)
+(setq byte-compile-warnings t)
 
 ;; need to use these variables for v18 support.
 ;; stifle the compiler.
